Module prelude

Module prelude 

Macros

join
Polls multiple futures simultaneously, returning a tuple of all results once complete.

Structs

Duration
A Duration type to represent a span of time, typically used for system timeouts.
EventEmitter
Event emitter for sending events to listeners.
EventListener
Event listener for receiving events.
Rc
A single-threaded reference-counting pointer. ‘Rc’ stands for ‘Reference Counted’.
Runtime
UnsafeCell
The core primitive for interior mutability in Rust.
Weak
Weak is a version of Rc that holds a non-owning reference to the managed allocation.

Traits

Component

Functions

run
sleep
Creates a new Sleep that will complete after the specified duration.
transmuteDeprecated
Reinterprets the bits of a value of one type as another type.

Attribute Macros

component